### eQuimageLab is a Python package to postprocess astronomical images with JupyterLab notebooks

Author: Yann-Michel Niquet (https://astro.ymniquet.fr)

Why use JupyterLab notebooks to process your images ?

  - You can easily modify/add/delete/move any operation in your workflow without the need to manually undo/redo the others.
  - You can tweak your notebook any time (shall you have new ideas to deal with an image) and reprocess in a few minutes.
  - You benefit from the full Python ecosystem to help you make the most out of your images (Numpy, Scikit-image, etc...).
  - ...

Enjoy the power of Python to process your images !

### Installation

eQuimageLab is developed in Python 3. To install the latest version of eQuimageLab, open a linux terminal/windows command prompt and run:

  `pip install --user eQuimageLab`

pip will automatically download eQuimageLab and the missing Python modules if necessary (Dash, Plotly, etc...). You can then launch eQuimageLab by typing:

  `eQuimagelab`

in this same terminal. You can also create a link to eQuimageLab from your desktop; an icon is distributed for this purpose with the Python package.

### Usage

The complete documentation is available at: https://astro.ymniquet.fr/codes/equimagelab/docs/

### Known bugs

